@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: ListLike
-version: 3.1.5
-id: ListLike-3.1.5-1befd1a7f59bc79b9d3424ec46d3fdf5
+version: 3.1.7.1
+id: ListLike-3.1.7.1-bff5f80e5207a62ce943ea3c8c57f69e
 
 license: BSD3
 copyright: Copyright (c) 2007-2008 John Goerzen
@@ -29,22 +29,22 @@ exposed-modules: Data.ListLike Data.ListLike.Base
                  Data.ListLike.Instances Data.ListLike.String Data.ListLike.Utils
 hidden-modules:
 trusted: False
-import-dirs: /usr/local/lib/ghc/ListLike-3.1.5
-library-dirs: /usr/local/lib/ghc/ListLike-3.1.5
-hs-libraries: HSListLike-3.1.5
+import-dirs: /usr/local/lib/ghc/ListLike-3.1.7.1
+library-dirs: /usr/local/lib/ghc/ListLike-3.1.7.1
+hs-libraries: HSListLike-3.1.7.1
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: array-0.4.0.0-4f6c2a594155b0b953c1cf0f54040f61
-         base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
-         bytestring-0.9.2.1-3c5b69d9d36e3a0179d120b97025ab86
-         containers-0.4.2.1-efa59805336a77490296ae3897cecb87
+depends: array-0.4.0.1-3b78425c10ff2dad7acf7e8c8ae014c3
+         base-4.6.0.1-6b06c3defb20732cfd08deb8ba52ca7c
+         bytestring-0.10.0.2-1c6ab0cabcb254a0e55d751d8ef17b51
+         containers-0.5.0.0-ab1dae9a94cd3cc84e7b2805636ebfa2
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-ListLike-3.1.5/html/ListLike.haddock
-haddock-html: /usr/local/share/doc/hs-ListLike-3.1.5/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-ListLike-3.1.7.1/html/ListLike.haddock
+haddock-html: /usr/local/share/doc/hs-ListLike-3.1.7.1/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
